@@ -10,7 +10,5 @@ def get_settings(mod_name=None, apps=(), middlewares=()):
     settings.INSTALLED_APPS += tuple(apps)
     settings.MIDDLEWARE_CLASSES = tuple(middlewares) + tuple(settings.MIDDLEWARE_CLASSES)
     settings.INTERNAL_IPS = ('127.0.0.1',)
-    from django.conf import settings as django_settings
-    django_settings.DEBUG_PROPAGATE_EXCEPTIONS = True
     return settings
 
